#!/bin/bash

# Properties
program_name="Tas Dev"

OPT_DIR="/opt/tctools"
sky_dir="$HOME/dev/sky"

. ${SCRIPT_DIR}/common_jboss.sh
. ${SCRIPT_DIR}/common_tas.sh

cmdArray=("installJava" "installJboss" "installMysql" "installAnt" "installGradle" "installGit" "setupTas" "setupSSH" "checkoutSKYP" "checkoutGCPS" "initDB" "initTas" "Quit")

skyp_ver=""
skyp_url=""
skyp_versions=(
	'skyprod-SKYP-2.3.11.30-OFF-20151113-1400.tar.gz=http://192.168.1.27:6500/tasshare/tpastore/SKY/OFF/2.3./skyprod-SKYP-2.3.11.30-OFF-20151113-1400.tar.gz'
	)
skyp_dir="${sky_dir}/systems/skyp"

function oneKeyInstall() {
	preInstall
	setupSSH

	setupApp
	installJava
	installJboss
	installMysql
	installOther
	setupTas
	setupProfile
	checkoutGCPS
	checkoutSKYP

	initDB
	initTas
	cd $CUR_DIR
}

function fullInstallWithDocker() {
	preInstall
	setupSSH
	selectDockerfile

	setupApp
	installJava
	installJboss
	installOther
	setupTas
	setupProfile
	checkoutGCPS
	checkoutSKYP

	imageOnly
	cd $CUR_DIR
}

function customInstall() {
	setupApp

	echo
	echo_line "Please select you want to execute."
	PS3='# '
	select cmdSel in "${cmdArray[@]}";
	do
		if [ "${cmdSel}" = "Quit" ]; then
			break
		else
			askUsername
			eval $cmdSel
			break
		fi
	done
}

function preInstall() {
	askUsername
	selectJboss
	selectTas
	selectJava

	addKnownHosts "gerrit.truetel.com"
	
	confirmInstall
}

function confirmInstall() {
	echo_color "======================================================================="
	echo_color "Ldap account:		${user_name}"
	echo_color "Java version:		JDK 1.8.0_45"
	echo_color "Gradle version:		${gradle_ver}"
	echo_color "Ant version:		${ant_ver}"
	echo_color "Git version:		${git_ver}"
	echo_color "Mysql version:		2.6"
	echo_color "Jboss version:		${jbossFileName}"
	echo_color "Jboss loction:		${jboss_home}"
	echo_color "TAS version:		${tasVer}"
	echo_color "TAS loction:		${tas_dir} -> ~/tashome"
	echo_color "Database name:		${tas_db}"
	if [ "$install_mode" = "${options[1]}" ]; then
		echo_color "Dockfiles:		"
	fi
	echo_color "======================================================================="

	echo_line "Please confirm install information, and press [Y] to install."
	while read -p "-> " -r -n 1 -s answer; do
	  if [[ $answer = [Yy] ]]; then
	    break
	  fi
	done
}

function setupSSH() {
	echo_color "-----------"
	echo_color " Setup SSH "
	echo_color "-----------"
	gogo
	if [ $pass = 1 ]; then
		return 1
	fi

	if [ ! -f ~/.ssh/id_rsa ] && [ ! -f ~/.ssh/id_dsa ]; then
		echo_line "creating ssh key pair ..."
		execCmd "ssh-keygen -t rsa -b 4096 -P '' -f ~/.ssh/id_rsa"
		echo_line "create ssh key pair done"
	fi

	echo_color "***************"
	echo_color "Please go to gerrit.truetel.com"
	echo_color "and register the following key below"
	echo_color "Please refer to Gerrit Migration Guide"
	echo_color "in tteng.truetel.com for instructions"
	echo_color "***************"

	if [ -f ~/.ssh/id_rsa.pub ]; then
		execCmd "cat ~/.ssh/id_rsa.pub"
	elif [ -f ~/.ssh/id_dsa.pub ]; then
		execCmd "cat ~/.ssh/id_dsa.pub"
	fi
	echo;echo

	echo_line "Please press [Y] after you ssh key has been registered."
	while read -p "-> " -r -n 1 -s answer; do
	  if [[ $answer = [Yy] ]]; then
	    break
	  fi
	done
}

function checkoutRepo() {
	tmpDir=`pwd`
	execCmd "cd ${sky_dir}"

	if [ ! -d $sky_dir/$1 ]; then
		execCmd "git clone \"ssh://$user_name@gerrit.truetel.com:29418/$1\""
	else
		execCmd "cd $1"
		execCmd "git reset --hard"
		execCmd "git pull"
	fi

	execCmd "cd ${tmpDir}"
}

function checkoutGCPS() {
	# must after setupProfile
	echo_color "---------------"
	echo_color " Checkout Code "
	echo_color "---------------"
	gogo
	if [ $pass = 1 ]; then
		return 1
	fi

	echo_line "Checking out sky source code... "
	mkDir $sky_dir
	
	checkoutRepo "systems"
	execCmd "cd ${sky_dir}/systems"

#	branchName=`git rev-parse --abbrev-ref HEAD`
#	if [ "${branchName}" = "TRN4NJN" ]; then
#		execCmd "git pull"
#	else
#		execCmd "git checkout -t origin/TRN4NJN"
#	fi
	
	execCmd "cd gcps"
	execCmd "gradle colatest cocustom"
	#execCmd "gradle forall -Pcmd=\"ant setup.eclipse.prj\""
	execCmd "cd $CUR_DIR"
	echo_line "Check out source code done"
}

function selectSKYP() {
	if [ "${skyp_ver}" = "" ] || [ "${skyp_url}" = "" ]; then
		if [ "${isFullInstall}" = true ]; then
		skyp_ver="${skyp_versions[0]%%=*}"
		skyp_url="${skyp_versions[0]##*=}"
		else
			echo_line "Please select SKYP version."
			arrayTmp=(${skyp_versions[@]})
			selectOption
			skyp_ver="${selKey}"
			skyp_url="${selVal}"

			resetSelectOption
		fi
	fi
}

function checkoutSKYP() {
	echo_color "---------------"
	echo_color " Checkout SKYP "
	echo_color "---------------"

	gogo
	if [ $pass = 1 ]; then
		return 1
	fi

	echo_line "Checking out sky source code... "
	mkDir $sky_dir

	selectSKYP

	if [ ! -f ${TMP_DIR}/${skyp_ver} ]; then
		echo_line "Download SKYP..."
		execCmd "wget -P $TMP_DIR ${skyp_url}"
	else
		echo_line "${skyp_ver} already exists... "
	fi

	if [ -d ${skyp_dir}/skyprod ]; then
		execCmd "rm -rf ${skyp_dir}/skyprod"
	fi

	echo_line "Unzip SKYP to ${skyp_dir}"
	execCmd "tar zxf ${TMP_DIR}/${skyp_ver} -C ${skyp_dir}"
}
