#!/bin/bash

tas_folder_name="tashome"
tas_loc="$HOME/tasdev"
tas_dir="${tas_loc}/${tas_folder_name}"
tas_db="tctas"
tas_versions=(
	'tasprod-TAS-OFF-R6V4P4-jboss-20160120-0938.tar.gz=http://192.168.1.26:6500/tasshare/tpastore/TAS/OFF/R6V4/tasprod-TAS-OFF-R6V4P4-jboss-20160120-0938.tar.gz'
	'tasprod-TAS-OFF-R6V4P3-jboss-20151223-1107.tar.gz=http://192.168.1.26:6500/tasshare/tpastore/TAS/OFF/R6V4/tasprod-TAS-OFF-R6V4P3-jboss-20151223-1107.tar.gz'
)
tas_ver=""
tas_url=""

function askTasInfo() {
	if [ ! "${install_mode}" = "${options[0]}" ]; then
		askTasLocal
		askTasFolderName
		askTasDB
	fi
}

function askTasFolderName() {
	echo_line "Please enter your tashome folder name. Press [ENTER] to use '${tas_folder_name}'."
	read -p "-> " tmp
	if [ ! "${tmp}" = "" ]; then
	    tas_folder_name="${tmp}"
	fi
	echo_color "Your tashome name: ${tas_folder_name}"
}

function askTasLocal() {
	echo_line "Please enter your tashome location. Press [ENTER] to put to '${tas_loc}'."
	read -p "-> " tmp
	if [ ! "${tmp}" = "" ]; then
	    tas_loc="${tmp}"
	fi
	echo_color "Your tashome location: ${tas_loc}/${tas_folder_name}"
}

function askTasDB() {
	echo_line "Please enter your database name. Press [ENTER] to use '${tas_db}'."
	read -p "-> " tmp
	if [ ! "${tmp}" = "" ]; then
	    tas_db="${tmp}"
	fi
	echo_color "Your database name: ${tas_db}"
}

function selectTas() {
	if [ "${tas_ver}" = "" ] || [ "${tas_url}" = "" ]; then
		if [ "${isFullInstall}" = true ]; then
			tas_ver="${tas_versions[0]%%=*}"
			tas_url="${tas_versions[0]##*=}"
		else
			echo_line "Please select TAS version."
			arrayTmp=(${tas_versions[@]})
			selectOption
			tas_ver="${selKey}"
			tas_url="${selVal}"

			resetSelectOption
		fi
	fi
}

function setupTas() {
	echo_color "-----------"
	echo_color " Setup Tas "
	echo_color "-----------"
	gogo
	if [ $pass = 1 ]; then
		return 1
	fi

	cd $CUR_DIR
	selectTas
	askTasInfo

	if [ ! -f ${TMP_DIR}/${tas_ver} ]; then
		echo_line "Download ${tas_selected} TAS..."
		execCmd "wget -P $TMP_DIR ${tas_url}"
	else
		echo_line "${tas_ver} already exists..."
	fi

	if [ ! -d $tas_dir ]; then
		execCmd "mkdir -p $tas_dir"
	else
		if [ -d $tas_dir/prod ]; then
			echo_line "Remove tashome prod."
			execCmd "rm -rf $tas_dir/prod/"
		fi
	fi

	echo_line "Unzip TAS to $tas_dir"
	execCmd "tar zxf ${TMP_DIR}/${tas_ver} -C $tas_dir"

	# setup dynamic link to tashome
	if [ ! -d ~/tashome ]; then
		echo_line "Create link ~/tashome to ${tas_dir}"
		execCmd "ln -s $tas_dir ~/tashome"
	fi

	setupTasrtenv
}

function setupTasrtenv() {
	echo_line "Setup tasrtenv.sh"

	if [ ! -d $tas_dir ]; then
		execCmd "mkdir -p $tas_dir"
	fi

	if [ ! -f $tas_dir/tasrtenv.sh ]; then
		if [ "$install_mode" = "${options[0]}" ]; then
			echo_line "Copy tasrtenv.sh from ${CONF_DIR}/tasrtenv.sh to $tas_dir/tasrtenv.sh"
			execCmd "cp ${CONF_DIR}/tasrtenv.sh $tas_dir/tasrtenv.sh"
			execCmd "sed -i'' -e \"s/export TAS_DB_URL=127.0.0.1:3306\/tctas/export TAS_DB_URL=127.0.0.1:3306\/${tas_db}/g\" $tas_dir/tasrtenv.sh"
		fi

		if [ "$install_mode" = "${options[1]}" ]; then
			if [ ! "$docker_sel_dir" = "" ]; then
				echo_line "Copy tasrtenv.sh from $docker_sel_dir/tasrtenv.sh to $tas_dir/tasrtenv.sh"
				execCmd "cp $docker_sel_dir/tasrtenv.sh $tas_dir/tasrtenv.sh"
			fi
		fi
	fi
}


function initDB() {
	echo_color "---------------------"
	echo_color " Executing initBD... "
	echo_color "---------------------"

	mysql -u root -e "GRANT all ON *.* TO 'tasadm'@'%' identified by 'tasadm';"
	mysql -u root -e "GRANT all ON *.* TO 'tasadm'@'localhost' identified by 'tasadm';"
	mysql -u root -e "CREATE DATABASE ${tas_db} DEFAULT CHARACTER SET utf8 DEFAULT COLLATE utf8_bin;"
}

function initTas() {
	echo_color "----------"
	echo_color " Init TAS "
	echo_color "----------"

	execCmd ". $tas_dir/tasrtenv.sh"
	execCmd "source $tas_dir/tasrtenv.sh"
	execCmd "taspatch.sh"
	execCmd "tasdbinit.sh"
}
